@@ -2,13 +2,13 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import product
-from . import location
-from . import production
+
+from . import location, product, production
 
 
 def register():
     Pool.register(
+        product.Template,
         product.Product,
         location.ProductLocation,
         location.Move,
