@@ -1,9 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.model import (ModelView, ModelSQL, MatchMixin, fields,
-    sequence_ordered)
-from trytond.pyson import If, Eval, Bool
+from trytond.model import (
+    MatchMixin, ModelSQL, ModelView, fields, sequence_ordered)
 from trytond.pool import PoolMeta
+from trytond.pyson import Bool, Eval, If
 
 
 class ProductLocation(sequence_ordered(), ModelSQL, ModelView, MatchMixin):
@@ -14,21 +14,19 @@ class ProductLocation(sequence_ordered(), ModelSQL, ModelView, MatchMixin):
     __name__ = 'stock.product.location'
     template = fields.Many2One(
         'product.template', "Product",
-        required=True, ondelete='CASCADE', select=True,
+        required=True, ondelete='CASCADE',
         domain=[
             If(Bool(Eval('product')),
                 ('products', '=', Eval('product')),
                 ()),
-            ],
-        depends=['product'])
+            ])
     product = fields.Many2One(
-        'product.product', "Variant", ondelete='CASCADE', select=True,
+        'product.product', "Variant", ondelete='CASCADE',
         domain=[
             If(Bool(Eval('template')),
                 ('template', '=', Eval('template')),
                 ()),
-            ],
-        depends=['template'])
+            ])
     warehouse = fields.Many2One('stock.location', 'Warehouse', required=True,
         domain=[('type', '=', 'warehouse')], ondelete='CASCADE')
     location = fields.Many2One('stock.location', 'Storage Location',
@@ -37,7 +35,7 @@ class ProductLocation(sequence_ordered(), ModelSQL, ModelView, MatchMixin):
             ('type', '=', 'storage'),
             ('parent', 'child_of', If(Bool(Eval('warehouse')),
                     [Eval('warehouse')], [])),
-            ], depends=['warehouse'])
+            ])
 
     @classmethod
     def __register__(cls, module_name):
